@@ -442,6 +442,7 @@ class App:
 
         have_all_expected_header_lines = True
         pull_line = True
+        line = ""
         for regex in [
             self.re_tasks,
             self.re_cpu,
@@ -480,7 +481,12 @@ class App:
                                         f"cpu{context.cpu_id}_{key}"
                                     ] = temp_dict.pop("cpu_" + key)
                                 context.current_entry.update(temp_dict)
-                                line = top_log.readline()
+
+                                # Handle multiple cpu_id blocks on a single line
+                                line = line[match.end():]
+                                line = line.lstrip()
+                                if not line:
+                                    line = top_log.readline()
                                 match = regex.match(line)
                             context.line_count -= 1
                         else:
@@ -509,6 +515,7 @@ class App:
 
             # Process header line
             line = top_log.readline()
+            process_header_pattern = ""
             if not self.re_process_header:
                 (
                     process_header_pattern,
@@ -685,6 +692,11 @@ class App:
     # --------------------------------------------------------------------------
     # Munge top's poi info
     def munge_poi_info(self):
+        acc_cpu = None
+        acc_mem = None
+        peak_cpu = None
+        peak_mem = None
+
         # Keep track of top N lists on request
         if self.config.poi_acc_cpu:
             acc_cpu = TopNDict2(
@@ -722,22 +734,22 @@ class App:
         for command in self.processes:
             for pid in self.processes[command]:
                 # Update top-N lists if required
-                if self.config.poi_acc_cpu:
+                if acc_cpu:
                     acc_cpu.append(
                         command, pid, self.processes[command][pid]["acc_cpu"]
                     )
 
-                if self.config.poi_acc_mem:
+                if acc_mem:
                     acc_mem.append(
                         command, pid, self.processes[command][pid]["acc_mem"]
                     )
 
-                if self.config.poi_peak_cpu:
+                if peak_cpu:
                     peak_cpu.append(
                         command, pid, self.processes[command][pid]["max_cpu"]
                     )
 
-                if self.config.poi_peak_mem:
+                if peak_mem:
                     peak_mem.append(
                         command, pid, self.processes[command][pid]["max_mem"]
                     )
