@@ -26,6 +26,11 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 
+class DummyEvent:
+    def __init__(self, artist, mouseevent):
+        self.artist = artist
+        self.mouseevent = mouseevent
+
 # -----------------------------------------------------------------------------
 # Class to abstract the management of Figs (windows)
 #
@@ -83,6 +88,8 @@ class FigManager:
         y,
         fig=None,
         subtitle=False,
+        *,
+        share_legends_regex=None
     ):
         self.name = name
         self.parent = parent
@@ -97,9 +104,15 @@ class FigManager:
         self.legmarkers = {}  # map legend lines  to legend line markers
         self.legtitles = {}  # map legend titles to plotted lines
         self.legotm = {}  # map otm legend elements to leglines from src legend
+        self.legotmtitles = {}  # map otm legend title to otm leglines
+        self.legotmtexts = {}  # map otm legend lines to otm legend texts and vice versa
 
         self.legends = {}  # map of extra legends (i.e. not ones that came with an axis)
 
+        # Used to indicate that clicks should be replicated or shared across all
+        # peering legends
+        self.share_legends_regex = share_legends_regex
+
         self.title, _, self.subtitle = title.partition("\n")
         self.fig = plt.figure() if fig is None else fig
         self.plots = self.fig.subplots(x, y)
@@ -126,6 +139,7 @@ class FigManager:
         _ = self.fig.canvas.mpl_connect("key_press_event", self.onkey)
         _ = self.fig.canvas.mpl_connect("close_event", self.onclose)
         _ = self.fig.canvas.mpl_connect("pick_event", self.onpick)
+        _ = self.fig.canvas.mpl_connect("motion_notify_event", self.onmove)
 
         self.help_text_box = None
         self.showing_help = 0
@@ -291,17 +305,17 @@ class FigManager:
                     print(f"CLASH: legline {legline} already present")
 
                 self.leglines[legline] = line
-                legline.set_pickradius(5)
+                legline.set_picker(5)
 
                 if legtext is not None:
                     self.leglines[legtext] = line
-                    legtext.set_picker(3)
+                    legtext.set_picker(10)
                     self.legtexts[legline] = legtext
                     self.legtexts[legtext] = legline
 
                 if handles is not None:
                     # pylint: disable=protected-access
-                    self.legmarkers[legline] = handles[i]._legmarker
+                    self.legmarkers[legline] = handles[i]
 
                 titleleglines.append(legline)
                 titlelines.append(line)
@@ -475,16 +489,40 @@ Page {page}   Version: {self.parent.config.version}    """
             del self.parent.fig_manager[self.name]
         self.parent.close_check()
 
+    # -------------------------------------------------------------------------
+    # Hook for motion
+    # This is intended to resolve occasional flickering issues without too much
+    # overhead. Flicker observed on Linux. Seems likely TkInter related.
+
+    onmove_counter = 0
+
+    def onmove(self, _):
+        self.onmove_counter += 1
+        if self.onmove_counter % 100 == 0:
+            self.fig.canvas.draw_idle()
+
     # -------------------------------------------------------------------------
     # Hook for artist picking
 
     def onpick(self, e):
-        if e.artist in self.legtitles:
-            self.on_legend_title_pick(e)
-        elif e.artist in self.legotm:
-            self.on_otm_legend_line_pick(e)
+        if isinstance(e.artist, mpl.legend.Legend):
+            # Not sure how/why these occur, but we're not interested
+            return
+
+        if self.share_legends_regex:
+            if e.artist in self.legtitles:
+                self.shared_legend_title_pick(e)
+            else:
+                self.shared_legend_line_pick(e)
         else:
-            self.on_legend_line_pick(e)
+            if e.artist in self.legtitles:
+                self.on_legend_title_pick(e)
+            elif e.artist in self.legotm:
+                self.on_otm_legend_line_pick(e)
+            elif e.artist in self.legotmtitles:
+                self.on_otm_legend_title_pick(e)
+            else:
+                self.on_legend_line_pick(e)
 
     # -------------------------------------------------------------------------
     # "Print" this fig to a file
@@ -529,13 +567,13 @@ Page {page}   Version: {self.parent.config.version}    """
     # -------------------------------------------------------------------------
     # Hook for legend title clicks
 
-    def on_legend_title_pick(self, event):
+    def on_legend_title_pick(self, e1, *, redraw=True):
         # on the pick event, find the orig line corresponding to the
         # legend proxy line, and toggle the visibility
-        pickee = event.artist
+        pickee = e1.artist
 
-        rmb = event.mouseevent.button == mpl.backend_bases.MouseButton.RIGHT
-        shift = event.mouseevent.key == "shift"
+        rmb = e1.mouseevent.button == mpl.backend_bases.MouseButton.RIGHT
+        shift = e1.mouseevent.key == "shift"
 
         for (i, line) in enumerate(self.legtitles[pickee]["lines"]):
             if rmb or shift:
@@ -550,19 +588,38 @@ Page {page}   Version: {self.parent.config.version}    """
             legline = self.legtitles[pickee]["leglines"][i]
             self.set_legline_alpha(legline, 1.0 if legvis else 0.2)
 
-        self.fig.canvas.draw()
+        if redraw:
+            self.fig.canvas.draw_idle()
+
+    # -------------------------------------------------------------------------
+    # Hook for legend title clicks with shared legends
+    # Note that this doesn't distinguish between legends. Any line in any legend
+    # may match.
+
+    def shared_legend_title_pick(self, e1):
+        text = e1.artist._text
+        for legend_title in self.legtitles:
+            if legend_title._text == text:
+                e2 = DummyEvent(legend_title, e1.mouseevent)
+                self.on_legend_title_pick(e2, redraw=False)
+
+        self.fig.canvas.draw_idle()
 
     # -------------------------------------------------------------------------
     # Hook for legend line clicks
 
-    def on_legend_line_pick(self, event, *, redraw=True):
+    def on_legend_line_pick(self, e1, *, redraw=True):
         # on the pick event, find the orig line corresponding to the
         # legend proxy line, and toggle the visibility
-        legline = event.artist
+        legline = e1.artist
+
+        rmb = e1.mouseevent.button == mpl.backend_bases.MouseButton.RIGHT
+        shift = e1.mouseevent.key == "shift"
+        force_visible = rmb or shift
 
         if legline in self.leglines:
             origline = self.leglines[legline]
-            vis = not origline.get_visible()
+            vis = True if force_visible else not origline.get_visible()
             origline.set_visible(vis)
 
             # Change the alpha on the line in the legend so we can see what lines
@@ -570,25 +627,86 @@ Page {page}   Version: {self.parent.config.version}    """
             self.set_legline_alpha(legline, 1.0 if vis else 0.2)
 
             if redraw:
-                self.fig.canvas.draw()
+                self.fig.canvas.draw_idle()
+
+    # -------------------------------------------------------------------------
+    # Hook for legend line clicks with shared legends
+
+    def shared_legend_line_pick(self, e1, *, redraw=True):
+        # Sort out legline and label : either could've been clicked to get here
+        # and we need the label to "click" all the peers in the shared legends.
+        if isinstance(e1.artist, mpl.lines.Line2D):
+            legline = e1.artist
+            label = self.legtexts[legline]
+        else:
+            label = e1.artist
+            legline = self.legtexts[label]
+
+        label_text = label._text
+
+        # Use regex because the label might need picking apart to extract
+        # partial content for comparison.
+        re_category = re.compile(self.share_legends_regex)
+
+        m = re_category.match(label_text)
+        category = m.group(1)
+
+        for line, text in self.legtexts.items():
+            m = re_category.match(text._label)
+            if m and m.group(1) == category:
+                e2 = DummyEvent(line, e1.mouseevent)
+                self.on_legend_line_pick(e2, redraw=False)
+
+        if redraw:
+            self.fig.canvas.draw_idle()
 
     # -------------------------------------------------------------------------
     # Hook for otm legend line clicks
     # Work actually done by the "real" legend's members.
 
-    def on_otm_legend_line_pick(self, e1):
-        legline = e1.artist
+    def on_otm_legend_line_pick(self, e1, *, redraw=True):
+        if isinstance(e1.artist, mpl.lines.Line2D):
+            legline = e1.artist
+            label = self.legotmtexts[legline]
+        else:
+            label = e1.artist
+            legline = self.legotmtexts[label]
 
-        class DummyEvent:
-            def __init__(self, artist):
-                self.artist = artist
+        rmb = e1.mouseevent.button == mpl.backend_bases.MouseButton.RIGHT
+        shift = e1.mouseevent.key == "shift"
+        force_visible = rmb or shift
 
-        # De-reference thie legend's element to the "real" legend's lines
+        # De-reference the legend's element to the "real" legend's lines
         for otmlegline in self.legotm[legline]:
-            e2 = DummyEvent(otmlegline)
+            e2 = DummyEvent(otmlegline, e1.mouseevent)
             self.on_legend_line_pick(e2, redraw=False)
 
-        self.fig.canvas.draw()
+        # Toggle the otm legend line and label
+        if force_visible:
+            alpha = 999
+        else:
+            alpha = legline.get_alpha()
+
+        # alpha is None (implying 1.0) if it's not already been explicitly set
+        alpha = 0.2 if (alpha is None or alpha == 1.0) else 1.0
+
+        legline.set_alpha(alpha)
+        label.set_alpha(alpha)
+
+        if redraw:
+            self.fig.canvas.draw_idle()
+
+    # -------------------------------------------------------------------------
+    # Hook for otm legend title clicks
+
+    def on_otm_legend_title_pick(self, e1):
+        otm_title = e1.artist
+
+        for otm_legline in self.legotmtitles[otm_title]:
+            e2 = DummyEvent(otm_legline, e1.mouseevent)
+            self.on_otm_legend_line_pick(e2, redraw=False)
+
+        self.fig.canvas.draw_idle()
 
     # -------------------------------------------------------------------------
     # Get the window to the top of the z-order
