@@ -352,7 +352,7 @@ class Grapher:
                 legelts = [figman.legtexts[legline], figman.legmarkers[legline]]
                 if category not in categories:
                     marker = (
-                        handle._legmarker.get_marker()  # pylint: disable=protected-access
+                        handle._marker.get_marker()  # pylint: disable=protected-access
                     )
                     marker = re_trailing_digits.sub("", marker, 1)
                     categories[category] = {
@@ -369,14 +369,14 @@ class Grapher:
         # Create shiney new legend lines
         new_handles = []
         new_labels = []
-        for category in categories:
-            extra_args = {"lw": categories[category]["lw"]}
+        for category, cat_data in categories.items():
+            extra_args = {"lw": cat_data["lw"]}
             if copy_markers:
-                extra_args["marker"] = categories[category]["marker"]
+                extra_args["marker"] = cat_data["marker"]
             line = mpl.lines.Line2D(
                 [],
                 [],
-                color=categories[category]["colour"],
+                color=cat_data["colour"],
                 label=category,
                 **extra_args,
             )
@@ -388,12 +388,20 @@ class Grapher:
         figman.register_legend(ax, legtitle, legend)
         legend.set_draggable(True)
 
+        # WARNING: going off mpl API here to access the artist of the legend's title box
+        title = legend._legend_title_box._text  # pylint: disable=protected-access
+        title.set_picker(10)
+        figman.legotmtitles[title] = []
+
         for (line, text) in zip(legend.get_lines(), legend.get_texts()):
             label = line.get_label()
-            line.set_pickradius(10)
+            line.set_picker(5)
             text.set_picker(10)
             figman.legotm[line] = categories[label]["lines"]
             figman.legotm[text] = categories[label]["lines"]
+            figman.legotmtitles[title].append(line)
+            figman.legotmtexts[line] = text
+            figman.legotmtexts[text] = line
 
         # Re-add src legend since it will have been detached by the
         # plt.legend([..]) call above
@@ -1124,6 +1132,7 @@ class Grapher:
                 self.window_size,
                 sqrt - excess_rows,
                 sqrt,
+                share_legends_regex=r"^cpu\d+ (.*)$"
             )
 
         self.dispense_graph(
@@ -1186,6 +1195,7 @@ class Grapher:
                 sqrt - excess_rows,
                 sqrt,
                 subtitle=True,
+                share_legends_regex="^(.*)$"
             )
 
         self.dispense_graph(
